@@ -8,10 +8,10 @@ LAYOUT_SINGLE = 'single'
 
 # カラム定義
 BIND_TYPE_FIXED = 'fixed'
-BIND_TYPE_SELECTABLE = 'selectable'
 BIND_TYPE_CALL = 'call'
+BIND_TYPE_EXTEND = 'extend'
 # カラム定義（特殊タイプ）
-BIND_TYPE_FOREIGN_KEY = 'foreign_key'
+BIND_TYPE_REFS = 'refs'
 BIND_TYPE_BLANK = ''
 
 # callのタイプ
